SFrout - Sales Force Report Downloader — sfrout 0.0.7 documentation

# SFrout - Sales Force Report Downloader

SFrout is a scalable, asynchronous SalesForce report downloader for SAML/SSO clients.

## What problem does this app solve?

In some organizations users are allowed to use only user interface with SSO authentication. No API, Security Tokens and other alternative connectors. This app automate authentication process, allow users to downloaded multiple SFDC reports, with custom parameteres, in asynchronous fashion.

## Main features:

- download single or multiple `SFDC` reports

- asynchronous requestes

- threaded IO processes

- queued transport

- fail safe, download the report or die trying

- dual interface, `importable package` / `CLI`

- logging to stdout / file

- summary report in `csv` and `console`

- dual report input format, `csv` / `list[dict]`

- progress displayed as `progress bar` or `console output`

- customizable number of workers

## The User Guide

If you plane to use SFrout this place is for you.

- Installation of SFrout
- Quickstart
- Advanced usage
- How does it work?

## The API Documentation

Let’s have a look under the hood.

- Main Interface
  - `run()`
  - cli
- Components
  - Config
    - `ConfigProtocol`
    - `Config`
  - Connectors
    - `ConnectorProtocol`
    - `SfdcConnector`
  - Containers
    - `ReportProtocol`
    - `ReportsContainerProtocol`
    - `SfdcReport`
    - `ReportsContainer`
  - Handlers
    - `WorkerFactoryProtocol`
    - `WorkerProtocol`
    - `WorkerFactory`
    - `Worker`
  - Excpetions
    - `OutdatedSIDError`
    - `EnvFileNotPresent`

# Indices and tables

- Index

- Module Index

- Search Page